#!/bin/bash
# creates an admin user account.

## === Argument Handling === ##
OPTIND=1  # Reset in case getopts has been used previously in this shell.

use_help=false
existing=false

while getopts "u:e:xh" opt; do
    case "$opt" in
    u)
        USER=$OPTARG
        ;;
    e)
        EMAIL=$OPTARG
        ;;
    x)
        existing=true
    h)
        use_help=true
        ;;
    esac
done

shift $((OPTIND-1))

[ "$1" = "--" ] && shift

# check if USER and EMAIL exists

if [ -z $USER ] ; then
    use_help=true
fi

if [ $use_help == true ] ; then
  echo 'Usage: -u <USERNAME> -e <EMAIL ADDRESS> -x -h'
  echo '-u the username to create'
  echo '-e the email address associated with account'
  echo '-x if the user already exists, promote to admin'
  echo '-h display this help menu'
  exit 0;
fi

. /usr/lib/ckan/default/bin/activate
cd /usr/lib/ckan/default/src/ckan

if [ existing ] ; then
  paster --plugin=ckan sysadmin add $USER --config=/etc/ckan/default/production.ini
else
  paster --plugin=ckan sysadmin add $USER email="${EMAIL}" --config=/etc/ckan/default/production.ini
fi