# @summary Installs the Landcare Research extension.
#
# **Requirements:**
#
#  Installs the following extensions.
#
# * ckan::ext::repeating
# * ckan::ext::ldap
#
# @param [String] uri
#   The uri to the ldap server to connect.
#   @example 'ldap://localhost:389'
#
# @param [String] base_dn
#   The ldap base dn to use for user authentication.
#   @example 'ou=users,dc=landcareresearch,dc=co,dc=nz'
#
# @param [String] source
#   The source of the git repository for this extension.
#
# @param [String] revision
#   The revision (or version) of the source to checkout with git.
#
# @param [String] ldap_revision
#   The revision (or version) of the ldap extension source to checkout with git.
#
# @param [String] ldap_source
#   The source of the ldap extension source to checkout with git.
#
# @param [String] organization_id
#   If this is set, users that log in using LDAP will automatically get added
#   to the given organization.
#
# The id can be found at the following url:
# http://<CKAN URL/api/action/organization_show?id=<ORG NAME>
#
class ckan::ext::lcrnz (
  String $uri,
  String $base_dn,
  Optional[String] $organization_id = undef,
  String $source                    =  'http://github.com/okfn/ckanext-lcrnz',
  String $revision                  = 'master',
  String $ldap_revision             = 'master',
  String $ldap_source               = 'ofkn',
  ){
  contain ckan::ext::repeating
  class {'ckan::ext::ldap':
    uri             => $uri,
    base_dn         => $base_dn,
    organization_id => $organization_id,
    source          => $ldap_source,
    revision        => $ldap_revision,
  }
  contain ckan::ext::ldap
  ckan::ext { 'lcrnz':
    source   => $source,
    revision => $revision,
    plugin   => ['lcrnz'],
  }
## Custom i18n folder (for replacing "organizations" with "collections")
## Update the path if necessary
#ckan.locale_default = en_NZ
#ckan.i18n_directory = /usr/lib/ckan/default/src/ckanext-lcrnz
}
