# @summary manages the apache configuration
#
class ckan::install::apache {

  file{'/etc/ckan/datapusher.wsgi':
    ensure => file,
    source => 'puppet:///modules/ckan/datapusher.wsgi',
  }

  file{'/etc/ckan/datapusher_settings.py':
    ensure  => file,
    source  => 'puppet:///modules/ckan/datapusher_settings.py',
    require => File['/etc/ckan/datapusher.wsgi'],
  }

  file{'/etc/ckan/default/apache.wsgi':
    ensure  => file,
    source  => 'puppet:///modules/ckan/apache.wsgi',
    require => File['/etc/ckan/datapusher_settings.py'],
  }


  class{'apache':
    default_vhost   => false,
    service_manage  => false,
    purge_configs   => true,
    purge_vhost_dir => true,
    timeout         => $ckan::apache_timeout,
    #require        => File['/etc/ckan/datapusher_settings.py'],
  }
  contain apache
  class{'apache::mod::wsgi':
    wsgi_socket_prefix  => '/var/run/wsgi',
  }
  contain apache::mod::wsgi
  contain apache::mod::rpaf

  apache::vhost{'default_ckan':
    port                        => '8080',
    ip                          => '0.0.0.0',
    servername                  => $ckan::server_name,
    serveraliases               => ["www.${ckan::server_name}"],
    error_log_file              => '/var/log/apache2/ckan_default.error.log',
    docroot                     => '/var/www',
    default_vhost               => true,
    directories                 => [{
      path     => '/',
      provider => 'directories',
      require  => 'all granted',
    }],
    wsgi_daemon_process         => 'ckan_default',
    wsgi_daemon_process_options =>
      { processes    => '2',
        threads      => '15',
        display-name => 'ckan_default',
      },
    wsgi_process_group          => 'ckan_default',
    wsgi_script_aliases         => { '/' => '/etc/ckan/default/apache.wsgi' },
    wsgi_pass_authorization     => 'on',
    custom_fragment             => "CustomLog /var/log/apache2/ckan_default.custom.log combined
    <IfModule mod_rpaf.c>
        RPAFenable On
        RPAFsethostname On
        RPAFproxy_ips 127.0.0.1
    </IfModule>",
  }

  apache::vhost{'datapusher':
    port                        => '8800',
    ip                          => '0.0.0.0',
    #servername                  => 'ckan',
    servername                  => $ckan::server_name,
    error_log_file              => '/var/log/apache2/datapusher.error.log',
    docroot                     => '/var/www',
    directories                 => [{
      path     => '/',
      provider => 'directories',
      require  => 'all granted',
    }],
    wsgi_daemon_process         => 'datapusher',
    wsgi_daemon_process_options =>
      { processes    => '1',
        threads      => '15',
        display-name => 'demo',
      },
    wsgi_process_group          => 'datapusher',
    wsgi_script_aliases         => { '/' => '/etc/ckan/datapusher.wsgi' },
    wsgi_pass_authorization     => 'on',
    custom_fragment             => 'CustomLog /var/log/apache2/datapusher.custom.log combined',
  }
}
